@@ -11,9 +11,9 @@ use Exporter qw(import);
 use List::Util qw(first max);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-02-18'; # DATE
+our $DATE = '2022-05-16'; # DATE
 our $DIST = 'Perinci-Result-Format-Lite'; # DIST
-our $VERSION = '0.286'; # VERSION
+our $VERSION = '0.287'; # VERSION
 
 our @EXPORT_OK = qw(format);
 
@@ -231,6 +231,8 @@ sub __gen_table {
     if ($format eq 'text-pretty') {
       ALIGN_COLUMNS:
         {
+            last unless @$data;
+
             # note: the logic of this block of code now also put in Number::Pad
 
             # XXX we just want to turn off 'uninitialized' and 'negative repeat
@@ -240,8 +242,23 @@ sub __gen_table {
             my $tfa         = $resmeta->{'table.field_aligns'};
             my $tfa_code    = $resmeta->{'table.field_align_code'};
             my $tfa_default = $resmeta->{'table.default_field_align'};
-            last unless $tfa || $tfa_code || $tfa_default;
-            last unless @$data;
+
+            # align numbers by default, with 'right' currently as 'number' is too slow
+            unless ($tfa || $tfa_code || $tfa_default) {
+                $tfa = [map { undef } 0 .. $#columns];
+              COLUMN:
+                for my $colidx (0 .. $#columns) {
+                    for my $i (0 .. $#{$data}) {
+                        next if $header_row && $i == 0;
+                        my $cell = $data->[$i][$colidx];
+                        next unless defined $cell;
+                        next COLUMN unless $cell =~ /\A[+-]?[0-9]+(?:\.[0-9]*)?(?:[Ee][+-]?[0-9]+)?(?:%)?\z/;
+                    }
+                    $tfa->[$colidx] = 'right';
+                }
+            }
+            #use DD; dd $tfa;
+            #say "D1";
 
             for my $colidx (0..$#columns) {
                 my $field_idx = $field_idxs[$colidx];
@@ -346,6 +363,7 @@ sub __gen_table {
                 }
             } # for $colidx
         } # END align columns
+        #say "D2";
 
         my $fres;
         my $backend = $ENV{FORMAT_PRETTY_TABLE_BACKEND};
@@ -551,7 +569,7 @@ Perinci::Result::Format::Lite - Format enveloped result
 
 =head1 VERSION
 
-This document describes version 0.286 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2022-02-18.
+This document describes version 0.287 of Perinci::Result::Format::Lite (from Perl distribution Perinci-Result-Format-Lite), released on 2022-05-16.
 
 =head1 SYNOPSIS
 
@@ -629,9 +647,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
